@@ -4,9 +4,9 @@ Main interface for mediatailor service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_mediatailor.type_defs import AvailSuppressionTypeDef
+    from mypy_boto3_mediatailor.type_defs import AdMarkerPassthroughTypeDef
 
-    data: AvailSuppressionTypeDef = {...}
+    data: AdMarkerPassthroughTypeDef = {...}
     ```
 """
 import sys
@@ -23,12 +23,14 @@ else:
 
 
 __all__ = (
+    "AdMarkerPassthroughTypeDef",
     "AvailSuppressionTypeDef",
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
     "DashConfigurationTypeDef",
     "HlsConfigurationTypeDef",
     "LivePreRollConfigurationTypeDef",
+    "ManifestProcessingRulesTypeDef",
     "PlaybackConfigurationTypeDef",
     "DashConfigurationForPutTypeDef",
     "GetPlaybackConfigurationResponseTypeDef",
@@ -38,6 +40,8 @@ __all__ = (
     "PutPlaybackConfigurationResponseTypeDef",
 )
 
+AdMarkerPassthroughTypeDef = TypedDict("AdMarkerPassthroughTypeDef", {"Enabled": bool}, total=False)
+
 AvailSuppressionTypeDef = TypedDict(
     "AvailSuppressionTypeDef",
     {"Mode": Literal["OFF", "BEHIND_LIVE_EDGE"], "Value": str},
@@ -72,6 +76,12 @@ LivePreRollConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+ManifestProcessingRulesTypeDef = TypedDict(
+    "ManifestProcessingRulesTypeDef",
+    {"AdMarkerPassthrough": "AdMarkerPassthroughTypeDef"},
+    total=False,
+)
+
 PlaybackConfigurationTypeDef = TypedDict(
     "PlaybackConfigurationTypeDef",
     {
@@ -81,6 +91,7 @@ PlaybackConfigurationTypeDef = TypedDict(
         "CdnConfiguration": "CdnConfigurationTypeDef",
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
+        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PlaybackConfigurationArn": str,
         "PlaybackEndpointPrefix": str,
@@ -110,6 +121,7 @@ GetPlaybackConfigurationResponseTypeDef = TypedDict(
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
         "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
         "PlaybackConfigurationArn": str,
@@ -147,6 +159,7 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
         "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
         "PlaybackConfigurationArn": str,
